@@ -12,6 +12,7 @@ use crate::utils::INTERNAL_MODE;
 use crate::Result;
 
 use anyhow::bail;
+use indexmap::IndexMap;
 use std::cell::RefCell;
 use std::collections::HashMap;
 use std::sync::Arc;
@@ -47,12 +48,17 @@ pub struct Command {
     pub(crate) names_checker: NamesChecker,
     pub(crate) root: Arc<RefCell<RootData>>,
     pub(crate) aliases: Vec<String>,
+    pub(crate) metadata: IndexMap<String, (String, Position)>,
 }
 
 impl Command {
     pub fn new(source: &str) -> Result<Self> {
         let events = parse(source)?;
-        Command::new_from_events(&events)
+        let mut root = Command::new_from_events(&events)?;
+        if root.metadata.contains_key("inherit-flag-options") {
+            root.inherit_flag_options();
+        }
+        Ok(root)
     }
 
     pub fn eval(
@@ -71,12 +77,12 @@ impl Command {
             } else {
                 &args[3..]
             };
-            let matcher = Matcher::new(self, new_args);
+            let matcher = Matcher::new(self, new_args, false);
             let mut arg_values = matcher.to_arg_values_for_choice_fn();
             arg_values.push(ArgcValue::ParamFn(args[2].clone()));
             return Ok(arg_values);
         }
-        let mut matcher = Matcher::new(self, args);
+        let mut matcher = Matcher::new(self, args, false);
         if let Some(script_path) = script_path {
             matcher.set_script_path(script_path)
         }
@@ -96,11 +102,17 @@ impl Command {
             .collect();
         let positional_params: Vec<serde_json::Value> =
             self.positional_params.iter().map(|v| v.to_json()).collect();
+        let mut metadata = serde_json::Map::new();
+        for (k, (v, _)) in &self.metadata {
+            metadata.insert(k.to_string(), serde_json::Value::String(v.to_string()));
+        }
+        let metadata = serde_json::Value::Object(metadata);
         serde_json::json!({
             "describe": self.describe,
             "name": self.name,
             "author": self.author,
             "version": self.version,
+            "metadata": metadata,
             "options": flag_option_params,
             "positionals": positional_params,
             "aliases": self.aliases,
@@ -126,6 +138,18 @@ impl Command {
                     let cmd = Self::get_cmd(&mut root_cmd, "@author", position)?;
                     cmd.author = Some(value);
                 }
+                EventData::Meta(key, value) => {
+                    let cmd = Self::get_cmd(&mut root_cmd, "@meta", position)?;
+                    if let Some((_, pos)) = cmd.metadata.get(&key) {
+                        bail!(
+                            "@meta(line {}) conflicts with '{}' at line {}",
+                            position,
+                            key,
+                            pos
+                        )
+                    }
+                    cmd.metadata.insert(key, (value, position));
+                }
                 EventData::Cmd(value) => {
                     if root_data.borrow().scope == EventScope::CmdStart {
                         bail!(
@@ -517,6 +541,25 @@ impl Command {
             .unwrap_or_default()
     }
 
+    fn inherit_flag_options(&mut self) {
+        for subcmd in self.subcommands.iter_mut() {
+            let mut inherited_flag_options = vec![];
+            for flag_option in &self.flag_option_params {
+                if subcmd.find_flag_option(flag_option.name()).is_none() {
+                    let mut flag_option = flag_option.clone();
+                    flag_option.inherit = true;
+                    inherited_flag_options.push(flag_option);
+                }
+            }
+            subcmd
+                .flag_option_params
+                .splice(..0, inherited_flag_options);
+        }
+        for subcmd in self.subcommands.iter_mut() {
+            subcmd.inherit_flag_options();
+        }
+    }
+
     fn add_positional_param(&mut self, param: PositionalParam, pos: Position) -> Result<()> {
         self.names_checker.check_positional(&param, pos)?;
         self.positional_params.push(param);
