@@ -182,6 +182,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                             subcmd,
                             arg,
                             arg_index,
+                            &mut is_rest_args_positional,
                         );
                     } else if let Some((mut arr, maybe_subcmd)) =
                         match_combine_shorts(cmd, arg, combine_shorts)
@@ -195,6 +196,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                                 subcmd,
                                 arg,
                                 arg_index,
+                                &mut is_rest_args_positional,
                             );
                             current_cmd = subcmd;
                         }
@@ -239,6 +241,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                         subcmd,
                         arg,
                         arg_index,
+                        &mut is_rest_args_positional,
                     );
                 } else {
                     add_positional_arg(
@@ -597,7 +600,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                 if let Some(param) = cmd.flag_option_params.iter().find(|v| v.name() == name) {
                     let values_list: Vec<&[&str]> =
                         indexes.iter().map(|v| args[*v].1.as_slice()).collect();
-                    if !param.multiple() && values_list.len() > 1 {
+                    if !param.multi_occurs() && values_list.len() > 1 {
                         return Some(MatchError::NotMultipleArgument(level, param.render_name()));
                     }
                     for values in values_list.iter() {
@@ -607,10 +610,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                                 param.render_name(),
                                 values[0].to_string(),
                             ));
-                        } else if (param.ellipsis()
-                            && values.len() + 1 < param.arg_value_names.len())
-                            || (!param.ellipsis() && values.len() != param.arg_value_names.len())
-                        {
+                        } else if !param.validate_args_len(values.len()) {
                             return Some(MatchError::MismatchValues(
                                 level,
                                 param.render_name_values(),
@@ -965,7 +965,7 @@ fn match_flag_option<'a, 'b>(
         flag_option_args.push((arg, value_args, Some(param.name())));
     } else {
         let mut values_len = param.arg_value_names.len();
-        if param.ellipsis() {
+        if param.unlimited_args() {
             values_len = usize::MAX / 2;
         }
         let args_len = args.len();
@@ -1019,7 +1019,11 @@ fn match_command<'a, 'b>(
     subcmd: &'a Command,
     arg: &'b str,
     arg_index: usize,
+    is_rest_args_positional: &mut bool,
 ) {
+    if subcmd.delegated() {
+        *is_rest_args_positional = true;
+    }
     *cmd_level += 1;
     cmds.push((arg, subcmd, arg_index));
     flag_option_args.push(vec![]);
@@ -1055,8 +1059,8 @@ fn comp_subcomands(cmd: &Command, flag: bool) -> Vec<CompItem> {
     let mut describe_help_subcmd = false;
     for subcmd in cmd.subcommands.iter() {
         let describe = subcmd.describe_head();
-        for v in subcmd.list_names() {
-            if v.len() < 2 {
+        for (i, v) in subcmd.list_names().into_iter().enumerate() {
+            if i > 0 && v.len() < 2 {
                 continue;
             }
             if (flag && v.starts_with('-')) || (!flag && !v.starts_with('-')) {
